==> verttice_ui-0.0.97.tar.gz: lib/src/widgets/data_factory/form_factory/time_form.dart <==
import 'package:verttice_logic/verttice_logic.dart';
import "package:verttice_ui/src/const/box_sizes.dart";
import "package:verttice_ui/src/const/icons.dart";
import "package:flutter/material.dart";
import 'package:day_night_time_picker/day_night_time_picker.dart';
import 'package:day_night_time_picker/lib/constants.dart';
import 'package:flutter/services.dart';
import 'package:verttice_ui/src/widgets/border_label.dart';
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';

class TimeFormFactory extends StatefulWidget {
  final String displayName;
  final String name;
  final dynamic value;
  final Function(String name, dynamic value) onChanged;
  final FormFieldState<dynamic>? state;

  const TimeFormFactory({
    Key? key,
    required this.value,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.state,
  }) : super(key: key);

  @override
  _TimeFormState createState() => _TimeFormState();
}

class _TimeFormState extends State<TimeFormFactory> {
  int _value = 0;

  @override
  void initState() {
    _value = DataClassUtils.dynamicToInt(widget.value, defultValue: 0)!;
    super.initState();
  }

  @override
  void didUpdateWidget(covariant TimeFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToInt(widget.value, defultValue: 0)!;
    }
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(builder: (context, constraints) {
      return BorderLabel(
        label: widget.displayName,
        onCopied: () async {
          await Clipboard.setData(
            ClipboardData(
              text: _value != 0
                  ? Dates.formatDataAndTime(
                      miliseconds: _value,
                      time: true,
                      date: false,
                    )
                  : "",
            ),
          );
          ThemedToast.info(
            context: context,
            message: "Copied to clipboard",
          );
        },
        actions: [
          PhysicalModel(
            color: Colors.grey,
            elevation: 5,
            shape: BoxShape.circle,
            child: CircleAvatar(
              backgroundColor: Colors.red,
              child: InkWell(
                child: ThemedIcons.clear(
                  iconStyle: IconStyle(
                    color: Colors.white,
                  ),
                ),
                onTap: () {
                  widget.onChanged(widget.name, null);
                  widget.state?.didChange(null);
                },
              ),
            ),
          ),
          sizedBoxW2,
        ],
        child: TextButton.icon(
          icon: ThemedIcons.time(),
          label: Text(
            _value != 0
                ? Dates.formatDataAndTime(
                    miliseconds: _value,
                    time: true,
                    date: false,
                  )
                : "",
          ),
          onPressed: () {
            showDialog(
              context: context,
              builder: (context) => AlertDialog(
                content: createInlinePicker(
                  value: TimeOfDay.fromDateTime(
                    _value != 0
                        ? DateTime.fromMillisecondsSinceEpoch(_value).toLocal()
                        : DateTime.now(),
                  ),
                  minuteInterval: MinuteInterval.FIVE,
                  onChange: (time) {
                    final currentDate = DateTime.fromMillisecondsSinceEpoch(0);
                    int timeInDate = DateTime(
                      currentDate.year,
                      currentDate.month,
                      currentDate.day,
                      time.hour,
                      time.minute,
                    ).toUtc().millisecondsSinceEpoch;

                    widget.onChanged(widget.name, timeInDate);
                    widget.state?.didChange(timeInDate);
                  },
                ),
              ),
            );
          },
        ),
      );
    });
  }
}

==> verttice_ui-0.0.150.tar.gz: lib/src/widgets/data_factory/form_factory/time_form.dart <==
// 🐦 Flutter imports:
import "package:flutter/material.dart";
import 'package:flutter/services.dart';

// 📦 Package imports:
import 'package:day_night_time_picker/day_night_time_picker.dart';
import 'package:day_night_time_picker/lib/constants.dart';
import 'package:verttice_logic/verttice_logic.dart';

// 🌎 Project imports:
import "package:verttice_ui/src/const/box_sizes.dart";
import "package:verttice_ui/src/const/icons.dart";
import 'package:verttice_ui/src/widgets/border_label.dart';
import 'package:verttice_ui/src/widgets/themed_widgets/themed_widgets_index.dart';

class TimeFormFactory extends StatefulWidget {
  final String displayName;
  final String name;
  final dynamic value;
  final Function(String name, dynamic value) onChanged;
  final FormFieldState<dynamic>? state;
  final String? tip;

  const TimeFormFactory({
    Key? key,
    required this.value,
    required this.onChanged,
    required this.displayName,
    required this.name,
    this.state,
    this.tip,
  }) : super(key: key);

  @override
  State<TimeFormFactory> createState() => _TimeFormState();
}

class _TimeFormState extends State<TimeFormFactory> {
  int _value = 0;

  @override
  void initState() {
    _value = DataClassUtils.dynamicToInt(widget.value, defaultValue: 0)!;
    super.initState();
  }

  @override
  void didUpdateWidget(covariant TimeFormFactory oldWidget) {
    super.didUpdateWidget(oldWidget);
    if (_value != widget.value) {
      _value = DataClassUtils.dynamicToInt(widget.value, defaultValue: 0)!;
    }
  }

  @override
  Widget build(BuildContext context) {
    return LayoutBuilder(builder: (context, constraints) {
      return BorderLabel(
        label: widget.displayName,
        tip: widget.tip,
        onCopied: () async {
          await Clipboard.setData(
            ClipboardData(
              text: _value != 0
                  ? Dates.formatDataAndTime(
                      milliseconds: _value,
                      time: true,
                      date: false,
                    )
                  : "",
            ),
          );
          ThemedToast.info(
            context: context,
            message: "Copied to clipboard",
          );
        },
        actions: [
          ThemedPhysicalModel(
            color: Colors.grey,
            elevation: 5,
            shape: BoxShape.circle,
            child: ThemedCircleAvatar(
              backgroundColor: Colors.red,
              child: InkWell(
                child: ThemedIcons.clear(
                  iconStyle: IconStyle(
                    color: Colors.white,
                  ),
                ),
                onTap: () {
                  widget.onChanged(widget.name, null);
                  widget.state?.didChange(null);
                },
              ),
            ),
          ),
          sizedBoxW2,
        ],
        child: ThemedCleanTextButton(
          _value != 0
              ? Dates.formatDataAndTime(
                  milliseconds: _value,
                  time: true,
                  date: false,
                )
              : "",
          icon: ThemedIcons.time(),
          onPressed: () {
            showDialog(
              context: context,
              builder: (context) => AlertDialog(
                content: createInlinePicker(
                  value: TimeOfDay.fromDateTime(
                    _value != 0
                        ? DateTime.fromMillisecondsSinceEpoch(_value).toLocal()
                        : DateTime.now(),
                  ),
                  minuteInterval: MinuteInterval.FIVE,
                  onChange: (time) {
                    final currentDate = DateTime.fromMillisecondsSinceEpoch(0);
                    int timeInDate = DateTime(
                      currentDate.year,
                      currentDate.month,
                      currentDate.day,
                      time.hour,
                      time.minute,
                    ).toUtc().millisecondsSinceEpoch;

                    widget.onChanged(widget.name, timeInDate);
                    widget.state?.didChange(timeInDate);
                  },
                ),
              ),
            );
          },
        ),
      );
    });
  }
}
